@@ -1,4 +1,5 @@
 import random
+
 def gensteam1():
     out = ""
     keys = "QWERTYUIOPASDFGHJKLZXCVBNM1234567890"
@@ -34,4 +35,16 @@ def genpass(length):
     for i in range(length):
         password += random.choice(chars)
     return password
-    
\ No newline at end of file
+    
+def xor_cipher(str, key):
+    encript_str = ""
+    for letter in str:
+        encript_str += chr(ord(letter)^key)
+    return encript_str
+    
+def SimpleStrHash(stre):
+    hash = 0
+    for i in stre:
+        hash += ord(i)
+        
+    return hex(hash)
\ No newline at end of file
